# nnthvn

## Описание
`nnthvn` — это простая библиотека для работы с числами и строками. 
## Реализованные функции
##

(def sum_of_squares(a, b, c),
##
Вывод:,
##
a**2 + b**2 + c**2,
##
def diff_max_min(a, b, c):,
##
Вывод:,
##
max(a, b, c) - min(a, b, c), sep=" ")


## Установка

pip install nnthvn


